---
title: Django SVCS
---

[![image](https://img.shields.io/pypi/v/django_svcs.svg)](https://pypi.python.org/pypi/django_svcs)

[![Documentation Status](https://readthedocs.org/projects/django-svcs/badge/?version=latest)](https://django-svcs.readthedocs.io/en/latest/?version=latest)

A Django integration for SVCS

-   Free software: BSD license
-   Documentation: <https://django-svcs.readthedocs.io>.

# Features

- Request-scoped and unscoped svcs registry selection
- Automatic configuration from apps by way of `<app>.services.svcs_init()` discovery
